@@ -230,8 +230,11 @@ fn get_href_attributes(html: String) -> PyResult<Vec<String>> {
         // .collect()
         .map(|x| {
             let attributes = x.attributes.borrow();
-            let href = attributes.get("href").unwrap();
-            href.to_string()
+            let href = attributes.get("href");
+            if href.is_none() {
+                return "".to_string();
+            }
+            href.unwrap().to_string()
         })
         .collect();
 
@@ -340,6 +343,7 @@ fn html_parsing_tools(_py: Python, m: &PyModule) -> PyResult<()> {
     m.add_function(wrap_pyfunction!(get_emails, m)?)?;
     m.add_function(wrap_pyfunction!(get_links, m)?)?;
     m.add_function(wrap_pyfunction!(html_contents, m)?)?;
+    m.add_function(wrap_pyfunction!(tag_html_contents, m)?)?;
     m.add_function(wrap_pyfunction!(get_sentences, m)?)?;
     m.add_function(wrap_pyfunction!(get_href_attributes, m)?)?;
     Ok(())
